@@ -25,7 +25,7 @@ int mm_support_check_and_show (void);
 	Returns 1 if MMX instructions are supported, 0 otherwise */
 int mmx_ok (void);
 
-extern int mm_flags;
+extern unsigned int mm_flags;
 
 /*static inline void emms(void)
 {
