@@ -7,12 +7,12 @@
 #include "main.h"
 #include "renderer.h"
 
-int playing, finished, reset,closed;
-int refreshed;
-short pcm_data[2][512];
-short freq_data[2][256];
-int pcm_count=0, freq_count=0;
-int tr;
+gint32 playing, finished, reset,closed;
+gint32 refreshed;
+gint16 pcm_data[2][512];
+gint16 freq_data[2][256];
+gint32 pcm_count=0, freq_count=0;
+gint32 tr;
 
 int main (int argc, char *argv[])
 {	
