@@ -1,7 +1,7 @@
 /**
  * \file types.h
  *
- * \brief Must be deprecated!
+ * \brief Must be deprecated?
  */
 
 /*
@@ -22,12 +22,13 @@
 #ifndef	__INFINITY_TYPES__
 #define __INFINITY_TYPES__
 
+#include <SDL/SDL.h>
 
 
 /**
  * Represents a single byte type.
  */
-typedef unsigned char byte;
+typedef Uint8 byte;
 
 
 #endif /* __INFINITY_TYPES__ */
